@@ -1,13 +1,12 @@
 //===----------------------------------------------------------------------===//
 //
-//                     The LLVM Compiler Infrastructure
-//
-// This file is dual licensed under the MIT and the University of Illinois Open
-// Source Licenses. See LICENSE.TXT for details.
+// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
+// See https://llvm.org/LICENSE.txt for license information.
+// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03
+// UNSUPPORTED: c++03
 
 // <map>
 
@@ -19,11 +18,12 @@
 #include <map>
 #include <cassert>
 
+#include "test_macros.h"
 #include "../../../Emplaceable.h"
 #include "DefaultOnly.h"
 #include "min_allocator.h"
 
-int main()
+int main(int, char**)
 {
     {
         typedef std::map<int, DefaultOnly> M;
@@ -39,18 +39,18 @@ int main()
         r = m.emplace_hint(m.end(), std::piecewise_construct,
                                        std::forward_as_tuple(1),
                                        std::forward_as_tuple());
-        assert(r == next(m.begin()));
+        assert(r == std::next(m.begin()));
         assert(m.size() == 2);
-        assert(next(m.begin())->first == 1);
-        assert(next(m.begin())->second == DefaultOnly());
+        assert(std::next(m.begin())->first == 1);
+        assert(std::next(m.begin())->second == DefaultOnly());
         assert(DefaultOnly::count == 2);
         r = m.emplace_hint(m.end(), std::piecewise_construct,
                                        std::forward_as_tuple(1),
                                        std::forward_as_tuple());
-        assert(r == next(m.begin()));
+        assert(r == std::next(m.begin()));
         assert(m.size() == 2);
-        assert(next(m.begin())->first == 1);
-        assert(next(m.begin())->second == DefaultOnly());
+        assert(std::next(m.begin())->first == 1);
+        assert(std::next(m.begin())->second == DefaultOnly());
         assert(DefaultOnly::count == 2);
     }
     assert(DefaultOnly::count == 0);
@@ -104,18 +104,18 @@ int main()
         r = m.emplace_hint(m.end(), std::piecewise_construct,
                                        std::forward_as_tuple(1),
                                        std::forward_as_tuple());
-        assert(r == next(m.begin()));
+        assert(r == std::next(m.begin()));
         assert(m.size() == 2);
-        assert(next(m.begin())->first == 1);
-        assert(next(m.begin())->second == DefaultOnly());
+        assert(std::next(m.begin())->first == 1);
+        assert(std::next(m.begin())->second == DefaultOnly());
         assert(DefaultOnly::count == 2);
         r = m.emplace_hint(m.end(), std::piecewise_construct,
                                        std::forward_as_tuple(1),
                                        std::forward_as_tuple());
-        assert(r == next(m.begin()));
+        assert(r == std::next(m.begin()));
         assert(m.size() == 2);
-        assert(next(m.begin())->first == 1);
-        assert(next(m.begin())->second == DefaultOnly());
+        assert(std::next(m.begin())->first == 1);
+        assert(std::next(m.begin())->second == DefaultOnly());
         assert(DefaultOnly::count == 2);
     }
     assert(DefaultOnly::count == 0);
@@ -155,4 +155,6 @@ int main()
         assert(m.begin()->first == 2);
         assert(m.begin()->second == 3.5);
     }
+
+  return 0;
 }
