@@ -8,10 +8,9 @@
 
 // <iostream>
 
-// istream cerr;
-
-// XFAIL: LIBCXX-WINDOWS-FIXME
+// ostream cerr;
 
+// UNSUPPORTED: executor-has-no-bash
 // FILE_DEPENDENCIES: ../check-stderr.sh
 // RUN: %{build}
 // RUN: %{exec} bash check-stderr.sh "%t.exe" "1234"
@@ -24,11 +23,6 @@
 int main(int, char**) {
     std::cerr << "1234";
     assert(std::cerr.flags() & std::ios_base::unitbuf);
-
-#ifdef _LIBCPP_HAS_NO_STDOUT
-    assert(std::cerr.tie() == NULL);
-#else
     assert(std::cerr.tie() == &std::cout);
-#endif
     return 0;
 }
