@@ -7,8 +7,6 @@
 //===----------------------------------------------------------------------===//
 
 // UNSUPPORTED: c++03, c++11, c++14, c++17
-// UNSUPPORTED: libcpp-no-concepts
-// UNSUPPORTED: gcc-10
 
 // ostreambuf_iterator
 
@@ -27,4 +25,6 @@ static_assert(!std::sized_sentinel_for<iterator, iterator>);
 static_assert(!std::input_iterator<iterator>);
 static_assert(std::indirectly_movable<char*, iterator>);
 static_assert(std::indirectly_movable_storable<char*, iterator>);
+static_assert(std::indirectly_copyable<char*, iterator>);
+static_assert(std::indirectly_copyable_storable<char*, iterator>);
 static_assert(!std::indirectly_swappable<iterator, iterator>);
