@@ -13,7 +13,7 @@
 // const charT* scan_is(mask m, const charT* low, const charT* high) const;
 
 // REQUIRES: locale.en_US.UTF-8
-// XFAIL: LIBCXX-WINDOWS-FIXME
+// XFAIL: no-wide-characters
 
 #include <locale>
 #include <string>
@@ -56,17 +56,23 @@ int main(int, char**)
             const std::wstring in(L"\x00DA A\x07.a1");
             std::vector<F::mask> m(in.size());
             assert(f.scan_is(F::space, in.data(), in.data() + in.size()) - in.data() == 1);
-            assert(f.scan_is(F::print, in.data(), in.data() + in.size()) - in.data() == 1);
             assert(f.scan_is(F::cntrl, in.data(), in.data() + in.size()) - in.data() == 3);
-            assert(f.scan_is(F::upper, in.data(), in.data() + in.size()) - in.data() == 2);
             assert(f.scan_is(F::lower, in.data(), in.data() + in.size()) - in.data() == 5);
-            assert(f.scan_is(F::alpha, in.data(), in.data() + in.size()) - in.data() == 2);
             assert(f.scan_is(F::digit, in.data(), in.data() + in.size()) - in.data() == 6);
             assert(f.scan_is(F::punct, in.data(), in.data() + in.size()) - in.data() == 4);
             assert(f.scan_is(F::xdigit, in.data(), in.data() + in.size()) - in.data() == 2);
             assert(f.scan_is(F::blank, in.data(), in.data() + in.size()) - in.data() == 1);
+#if !defined(_WIN32)
+            // On Windows, these wchars are classified according to their
+            // Unicode interpretation even in the "C" locale, where
+            // the scan_is function returns the same as above for the
+            // en_US.UTF-8 locale.
+            assert(f.scan_is(F::print, in.data(), in.data() + in.size()) - in.data() == 1);
+            assert(f.scan_is(F::upper, in.data(), in.data() + in.size()) - in.data() == 2);
+            assert(f.scan_is(F::alpha, in.data(), in.data() + in.size()) - in.data() == 2);
             assert(f.scan_is(F::alnum, in.data(), in.data() + in.size()) - in.data() == 2);
             assert(f.scan_is(F::graph, in.data(), in.data() + in.size()) - in.data() == 2);
+#endif
         }
     }
 
