@@ -8,7 +8,7 @@
 
 // <string>
 
-// size_type size() const;
+// size_type size() const; // constexpr since C++20
 
 #include <string>
 #include <cassert>
@@ -17,27 +17,33 @@
 #include "min_allocator.h"
 
 template <class S>
-void
+TEST_CONSTEXPR_CXX20 void
 test(const S& s, typename S::size_type c)
 {
     assert(s.size() == c);
 }
 
+template <class S>
+TEST_CONSTEXPR_CXX20 void test_string() {
+  test(S(), 0);
+  test(S("123"), 3);
+  test(S("12345678901234567890123456789012345678901234567890"), 50);
+}
+
+TEST_CONSTEXPR_CXX20 bool test() {
+  test_string<std::string>();
+#if TEST_STD_VER >= 11
+  test_string<std::basic_string<char, std::char_traits<char>, min_allocator<char>>>();
+#endif
+
+  return true;
+}
+
 int main(int, char**)
 {
-    {
-    typedef std::string S;
-    test(S(), 0);
-    test(S("123"), 3);
-    test(S("12345678901234567890123456789012345678901234567890"), 50);
-    }
-#if TEST_STD_VER >= 11
-    {
-    typedef std::basic_string<char, std::char_traits<char>, min_allocator<char>> S;
-    test(S(), 0);
-    test(S("123"), 3);
-    test(S("12345678901234567890123456789012345678901234567890"), 50);
-    }
+  test();
+#if TEST_STD_VER > 17
+  static_assert(test());
 #endif
 
   return 0;
