@@ -28,7 +28,6 @@ constexpr bool test_constexpr()
 
 int main(int, char**)
 {
-#ifndef _LIBCPP_HAS_NO_UNICODE_CHARS
 #if TEST_STD_VER >= 11
     assert(std::char_traits<char16_t>::length(u"") == 0);
     assert(std::char_traits<char16_t>::length(u"a") == 1);
@@ -40,7 +39,6 @@ int main(int, char**)
 #if TEST_STD_VER > 14
     static_assert(test_constexpr(), "" );
 #endif
-#endif // _LIBCPP_HAS_NO_UNICODE_CHARS
 
   return 0;
 }
