@@ -8,12 +8,11 @@
 
 // UNSUPPORTED: c++03, c++11, c++14
 
-// Throwing bad_any_cast is supported starting in macosx10.13
-// XFAIL: use_system_cxx_lib && target={{.+}}-apple-macosx10.{{9|10|11|12}} && !no-exceptions
+// XFAIL: availability-bad_any_cast-missing && !no-exceptions
 
 // <any>
 
-// any& operator=(any const &);
+// any& operator=(const any&);
 
 // Test copy assignment
 
@@ -24,9 +23,6 @@
 #include "count_new.h"
 #include "test_macros.h"
 
-using std::any;
-using std::any_cast;
-
 template <class LHS, class RHS>
 void test_copy_assign() {
     assert(LHS::count == 0);
@@ -34,8 +30,8 @@ void test_copy_assign() {
     LHS::reset();
     RHS::reset();
     {
-        any lhs(LHS(1));
-        any const rhs(RHS(2));
+        std::any lhs = LHS(1);
+        const std::any rhs = RHS(2);
 
         assert(LHS::count == 1);
         assert(RHS::count == 1);
@@ -59,8 +55,8 @@ void test_copy_assign_empty() {
     assert(LHS::count == 0);
     LHS::reset();
     {
-        any lhs;
-        any const rhs(LHS(42));
+        std::any lhs;
+        const std::any rhs = LHS(42);
 
         assert(LHS::count == 1);
         assert(LHS::copied == 0);
@@ -76,8 +72,8 @@ void test_copy_assign_empty() {
     assert(LHS::count == 0);
     LHS::reset();
     {
-        any lhs(LHS(1));
-        any const rhs;
+        std::any lhs = LHS(1);
+        const std::any rhs;
 
         assert(LHS::count == 1);
         assert(LHS::copied == 0);
@@ -96,18 +92,18 @@ void test_copy_assign_empty() {
 void test_copy_assign_self() {
     // empty
     {
-        any a;
-        a = (any &)a;
+        std::any a;
+        a = (std::any&)a;
         assertEmpty(a);
         assert(globalMemCounter.checkOutstandingNewEq(0));
     }
     assert(globalMemCounter.checkOutstandingNewEq(0));
     // small
     {
-        any a((small(1)));
+        std::any a = small(1);
         assert(small::count == 1);
 
-        a = (any &)a;
+        a = (std::any&)a;
 
         assert(small::count == 1);
         assertContains<small>(a, 1);
@@ -117,10 +113,10 @@ void test_copy_assign_self() {
     assert(globalMemCounter.checkOutstandingNewEq(0));
     // large
     {
-        any a(large(1));
+        std::any a = large(1);
         assert(large::count == 1);
 
-        a = (any &)a;
+        a = (std::any&)a;
 
         assert(large::count == 1);
         assertContains<large>(a, 1);
@@ -135,11 +131,11 @@ void test_copy_assign_throws()
 {
 #if !defined(TEST_HAS_NO_EXCEPTIONS)
     auto try_throw =
-    [](any& lhs, any const& rhs) {
+    [](std::any& lhs, const std::any& rhs) {
         try {
             lhs = rhs;
             assert(false);
-        } catch (my_any_exception const &) {
+        } catch (const my_any_exception&) {
             // do nothing
         } catch (...) {
             assert(false);
@@ -147,8 +143,8 @@ void test_copy_assign_throws()
     };
     // const lvalue to empty
     {
-        any lhs;
-        any const rhs((Tp(1)));
+        std::any lhs;
+        const std::any rhs = Tp(1);
         assert(Tp::count == 1);
 
         try_throw(lhs, rhs);
@@ -158,8 +154,8 @@ void test_copy_assign_throws()
         assertContains<Tp>(rhs, 1);
     }
     {
-        any lhs((small(2)));
-        any const rhs((Tp(1)));
+        std::any lhs = small(2);
+        const std::any rhs = Tp(1);
         assert(small::count == 1);
         assert(Tp::count == 1);
 
@@ -171,8 +167,8 @@ void test_copy_assign_throws()
         assertContains<Tp>(rhs, 1);
     }
     {
-        any lhs((large(2)));
-        any const rhs((Tp(1)));
+        std::any lhs = large(2);
+        const std::any rhs = Tp(1);
         assert(large::count == 1);
         assert(Tp::count == 1);
 
