@@ -6,7 +6,7 @@
 //
 //===----------------------------------------------------------------------===//
 
-// UNSUPPORTED: c++98, c++03
+// UNSUPPORTED: c++03
 
 // <memory>
 
@@ -15,7 +15,9 @@
 
 #include <memory>
 
-#include "poisoned_hash_helper.hpp"
+#include <functional>
+
+#include "poisoned_hash_helper.h"
 
 #include "test_macros.h"
 
